@@ -27,20 +27,23 @@ rvalueGuts <- function(dat, alpha.grid, V, vfun, hypers, smooth) {
   }
   ### Think of ccfun as the lambda_{\alpha} function
   
-  dfun <- function(alpha, unitdata, hypers)
-  {
-    dd <- ccfun(alpha) - vfun(alpha, unitdata, hypers)
-    dd
-  }
+  #dfun <- function(alpha, unitdata, hypers)
+  #{
+ #   dd <- ccfun(alpha) - vfun(alpha, unitdata, hypers)
+  #  dd
+  #}
   ## march through units finding rvalue by uniroot
   ### What if there are multiple roots? (This may be possible if ccfun is not monotonic)
   #rvals <- numeric(nunits)
   #for( i in 1:nunits ) {
-  #   rvals[i] <- uniroot(dfun,interval=c(0,1),unitdata=dat[i,],hypers=hypers)$root
+  #   rvals[i] <- uniroot(dfun,interval=c(0,1),unitdata=dat[i,],hypers=hypers, tol=1e-10)$root
   #}
-  rvals <- mroot(dfun, lower=rep(0,nunits), upper=rep(1,nunits), unitdata=dat, 
-                 hypers=hypers)$root
-    
+  #rvals <- mroot(dfun, lower=rep(0,nunits), upper=rep(1,nunits), unitdata=dat, 
+  #               hypers=hypers, tol=1e-6)$root
+  rvals <- VVcut(V, cc, nunits, ngrid, alpha.grid)
+  ## maybe go back to root finding?
+  #rvals <- alpha.grid[tmp]
+  
   ans <- list()
   ans$rvals <- rvals
   ans$lamfun <- cc
@@ -53,8 +56,10 @@ vfun.pg <- function( alpha, unitdata, hypers ) {
   ## Poisson Gamma posterior upper tail probability
   aa <- hypers[1]
   bb <- hypers[2]  ## hyper params of Gamma prior
-  x <- unitdata[,1]
-  et <- unitdata[,2]	
+  #x <- unitdata[,1]
+  #et <- unitdata[,2]	
+  x <- unitdata[1]
+  et <- unitdata[2]
   tAlpha <- qgamma(alpha, shape=aa, rate=bb, lower.tail=FALSE )
   p <- pgamma(tAlpha, shape=(aa+x), rate=(bb+et), lower.tail=FALSE )
   p
